@@ -10,11 +10,23 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    IResolvable as _IResolvable_9ceae33e,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    IInspectable as _IInspectable_051e6ed8,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_directoryservice.CfnMicrosoftAD"):
+class CfnMicrosoftAD(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_directoryservice.CfnMicrosoftAD",
+):
     """A CloudFormation ``AWS::DirectoryService::MicrosoftAD``.
 
     see
@@ -22,7 +34,20 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
     cloudformationResource:
     :cloudformationResource:: AWS::DirectoryService::MicrosoftAD
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, name: str, password: str, vpc_settings: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e], create_alias: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, edition: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, short_name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        name: str,
+        password: str,
+        vpc_settings: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e],
+        create_alias: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        edition: typing.Optional[str] = None,
+        enable_sso: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        short_name: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::DirectoryService::MicrosoftAD``.
 
         :param scope: - scope in which this resource is defined.
@@ -35,13 +60,28 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         :param enable_sso: ``AWS::DirectoryService::MicrosoftAD.EnableSso``.
         :param short_name: ``AWS::DirectoryService::MicrosoftAD.ShortName``.
         """
-        props = CfnMicrosoftADProps(name=name, password=password, vpc_settings=vpc_settings, create_alias=create_alias, edition=edition, enable_sso=enable_sso, short_name=short_name)
+        props = CfnMicrosoftADProps(
+            name=name,
+            password=password,
+            vpc_settings=vpc_settings,
+            create_alias=create_alias,
+            edition=edition,
+            enable_sso=enable_sso,
+            short_name=short_name,
+        )
 
         jsii.create(CfnMicrosoftAD, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnMicrosoftAD":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnMicrosoftAD":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -56,7 +96,9 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -70,7 +112,9 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -135,7 +179,9 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
 
     @builtins.property
     @jsii.member(jsii_name="vpcSettings")
-    def vpc_settings(self) -> typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e]:
+    def vpc_settings(
+        self,
+    ) -> typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e]:
         """``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
 
         see
@@ -144,12 +190,16 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "vpcSettings")
 
     @vpc_settings.setter
-    def vpc_settings(self, value: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e]) -> None:
+    def vpc_settings(
+        self, value: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e]
+    ) -> None:
         jsii.set(self, "vpcSettings", value)
 
     @builtins.property
     @jsii.member(jsii_name="createAlias")
-    def create_alias(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def create_alias(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
         see
@@ -158,7 +208,9 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "createAlias")
 
     @create_alias.setter
-    def create_alias(self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]) -> None:
+    def create_alias(
+        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+    ) -> None:
         jsii.set(self, "createAlias", value)
 
     @builtins.property
@@ -186,7 +238,9 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "enableSso")
 
     @enable_sso.setter
-    def enable_sso(self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]) -> None:
+    def enable_sso(
+        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+    ) -> None:
         jsii.set(self, "enableSso", value)
 
     @builtins.property
@@ -203,8 +257,12 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
     def short_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "shortName", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_directoryservice.CfnMicrosoftAD.VpcSettingsProperty", jsii_struct_bases=[], name_mapping={'subnet_ids': 'subnetIds', 'vpc_id': 'vpcId'})
-    class VpcSettingsProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_directoryservice.CfnMicrosoftAD.VpcSettingsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"subnet_ids": "subnetIds", "vpc_id": "vpcId"},
+    )
+    class VpcSettingsProperty:
         def __init__(self, *, subnet_ids: typing.List[str], vpc_id: str) -> None:
             """
             :param subnet_ids: ``CfnMicrosoftAD.VpcSettingsProperty.SubnetIds``.
@@ -214,8 +272,8 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html
             """
             self._values = {
-                'subnet_ids': subnet_ids,
-                'vpc_id': vpc_id,
+                "subnet_ids": subnet_ids,
+                "vpc_id": vpc_id,
             }
 
         @builtins.property
@@ -225,7 +283,7 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html#cfn-directoryservice-microsoftad-vpcsettings-subnetids
             """
-            return self._values.get('subnet_ids')
+            return self._values.get("subnet_ids")
 
         @builtins.property
         def vpc_id(self) -> str:
@@ -234,7 +292,7 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html#cfn-directoryservice-microsoftad-vpcsettings-vpcid
             """
-            return self._values.get('vpc_id')
+            return self._values.get("vpc_id")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -243,13 +301,38 @@ class CfnMicrosoftAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'VpcSettingsProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "VpcSettingsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_directoryservice.CfnMicrosoftADProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'password': 'password', 'vpc_settings': 'vpcSettings', 'create_alias': 'createAlias', 'edition': 'edition', 'enable_sso': 'enableSso', 'short_name': 'shortName'})
-class CfnMicrosoftADProps():
-    def __init__(self, *, name: str, password: str, vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e], create_alias: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, edition: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, short_name: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_directoryservice.CfnMicrosoftADProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "name": "name",
+        "password": "password",
+        "vpc_settings": "vpcSettings",
+        "create_alias": "createAlias",
+        "edition": "edition",
+        "enable_sso": "enableSso",
+        "short_name": "shortName",
+    },
+)
+class CfnMicrosoftADProps:
+    def __init__(
+        self,
+        *,
+        name: str,
+        password: str,
+        vpc_settings: typing.Union[
+            "CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e
+        ],
+        create_alias: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        edition: typing.Optional[str] = None,
+        enable_sso: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        short_name: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::DirectoryService::MicrosoftAD``.
 
         :param name: ``AWS::DirectoryService::MicrosoftAD.Name``.
@@ -264,14 +347,18 @@ class CfnMicrosoftADProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html
         """
         self._values = {
-            'name': name,
-            'password': password,
-            'vpc_settings': vpc_settings,
+            "name": name,
+            "password": password,
+            "vpc_settings": vpc_settings,
         }
-        if create_alias is not None: self._values["create_alias"] = create_alias
-        if edition is not None: self._values["edition"] = edition
-        if enable_sso is not None: self._values["enable_sso"] = enable_sso
-        if short_name is not None: self._values["short_name"] = short_name
+        if create_alias is not None:
+            self._values["create_alias"] = create_alias
+        if edition is not None:
+            self._values["edition"] = edition
+        if enable_sso is not None:
+            self._values["enable_sso"] = enable_sso
+        if short_name is not None:
+            self._values["short_name"] = short_name
 
     @builtins.property
     def name(self) -> str:
@@ -280,7 +367,7 @@ class CfnMicrosoftADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def password(self) -> str:
@@ -289,25 +376,29 @@ class CfnMicrosoftADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
         """
-        return self._values.get('password')
+        return self._values.get("password")
 
     @builtins.property
-    def vpc_settings(self) -> typing.Union["CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e]:
+    def vpc_settings(
+        self,
+    ) -> typing.Union["CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e]:
         """``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
         """
-        return self._values.get('vpc_settings')
+        return self._values.get("vpc_settings")
 
     @builtins.property
-    def create_alias(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def create_alias(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-createalias
         """
-        return self._values.get('create_alias')
+        return self._values.get("create_alias")
 
     @builtins.property
     def edition(self) -> typing.Optional[str]:
@@ -316,7 +407,7 @@ class CfnMicrosoftADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-edition
         """
-        return self._values.get('edition')
+        return self._values.get("edition")
 
     @builtins.property
     def enable_sso(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
@@ -325,7 +416,7 @@ class CfnMicrosoftADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-enablesso
         """
-        return self._values.get('enable_sso')
+        return self._values.get("enable_sso")
 
     @builtins.property
     def short_name(self) -> typing.Optional[str]:
@@ -334,7 +425,7 @@ class CfnMicrosoftADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-shortname
         """
-        return self._values.get('short_name')
+        return self._values.get("short_name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -343,11 +434,17 @@ class CfnMicrosoftADProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnMicrosoftADProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnMicrosoftADProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_directoryservice.CfnSimpleAD"):
+class CfnSimpleAD(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_directoryservice.CfnSimpleAD",
+):
     """A CloudFormation ``AWS::DirectoryService::SimpleAD``.
 
     see
@@ -355,7 +452,21 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
     cloudformationResource:
     :cloudformationResource:: AWS::DirectoryService::SimpleAD
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, name: str, password: str, size: str, vpc_settings: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e], create_alias: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, description: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, short_name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        name: str,
+        password: str,
+        size: str,
+        vpc_settings: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e],
+        create_alias: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        description: typing.Optional[str] = None,
+        enable_sso: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        short_name: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::DirectoryService::SimpleAD``.
 
         :param scope: - scope in which this resource is defined.
@@ -369,13 +480,29 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         :param enable_sso: ``AWS::DirectoryService::SimpleAD.EnableSso``.
         :param short_name: ``AWS::DirectoryService::SimpleAD.ShortName``.
         """
-        props = CfnSimpleADProps(name=name, password=password, size=size, vpc_settings=vpc_settings, create_alias=create_alias, description=description, enable_sso=enable_sso, short_name=short_name)
+        props = CfnSimpleADProps(
+            name=name,
+            password=password,
+            size=size,
+            vpc_settings=vpc_settings,
+            create_alias=create_alias,
+            description=description,
+            enable_sso=enable_sso,
+            short_name=short_name,
+        )
 
         jsii.create(CfnSimpleAD, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnSimpleAD":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnSimpleAD":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -390,7 +517,9 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -404,7 +533,9 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -483,7 +614,9 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
 
     @builtins.property
     @jsii.member(jsii_name="vpcSettings")
-    def vpc_settings(self) -> typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e]:
+    def vpc_settings(
+        self,
+    ) -> typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e]:
         """``AWS::DirectoryService::SimpleAD.VpcSettings``.
 
         see
@@ -492,12 +625,16 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         return jsii.get(self, "vpcSettings")
 
     @vpc_settings.setter
-    def vpc_settings(self, value: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e]) -> None:
+    def vpc_settings(
+        self, value: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e]
+    ) -> None:
         jsii.set(self, "vpcSettings", value)
 
     @builtins.property
     @jsii.member(jsii_name="createAlias")
-    def create_alias(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def create_alias(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
         see
@@ -506,7 +643,9 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         return jsii.get(self, "createAlias")
 
     @create_alias.setter
-    def create_alias(self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]) -> None:
+    def create_alias(
+        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+    ) -> None:
         jsii.set(self, "createAlias", value)
 
     @builtins.property
@@ -534,7 +673,9 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         return jsii.get(self, "enableSso")
 
     @enable_sso.setter
-    def enable_sso(self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]) -> None:
+    def enable_sso(
+        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+    ) -> None:
         jsii.set(self, "enableSso", value)
 
     @builtins.property
@@ -551,8 +692,12 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
     def short_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "shortName", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_directoryservice.CfnSimpleAD.VpcSettingsProperty", jsii_struct_bases=[], name_mapping={'subnet_ids': 'subnetIds', 'vpc_id': 'vpcId'})
-    class VpcSettingsProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_directoryservice.CfnSimpleAD.VpcSettingsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"subnet_ids": "subnetIds", "vpc_id": "vpcId"},
+    )
+    class VpcSettingsProperty:
         def __init__(self, *, subnet_ids: typing.List[str], vpc_id: str) -> None:
             """
             :param subnet_ids: ``CfnSimpleAD.VpcSettingsProperty.SubnetIds``.
@@ -562,8 +707,8 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html
             """
             self._values = {
-                'subnet_ids': subnet_ids,
-                'vpc_id': vpc_id,
+                "subnet_ids": subnet_ids,
+                "vpc_id": vpc_id,
             }
 
         @builtins.property
@@ -573,7 +718,7 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html#cfn-directoryservice-simplead-vpcsettings-subnetids
             """
-            return self._values.get('subnet_ids')
+            return self._values.get("subnet_ids")
 
         @builtins.property
         def vpc_id(self) -> str:
@@ -582,7 +727,7 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html#cfn-directoryservice-simplead-vpcsettings-vpcid
             """
-            return self._values.get('vpc_id')
+            return self._values.get("vpc_id")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -591,13 +736,40 @@ class CfnSimpleAD(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'VpcSettingsProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "VpcSettingsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_directoryservice.CfnSimpleADProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'password': 'password', 'size': 'size', 'vpc_settings': 'vpcSettings', 'create_alias': 'createAlias', 'description': 'description', 'enable_sso': 'enableSso', 'short_name': 'shortName'})
-class CfnSimpleADProps():
-    def __init__(self, *, name: str, password: str, size: str, vpc_settings: typing.Union["CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e], create_alias: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, description: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, short_name: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_directoryservice.CfnSimpleADProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "name": "name",
+        "password": "password",
+        "size": "size",
+        "vpc_settings": "vpcSettings",
+        "create_alias": "createAlias",
+        "description": "description",
+        "enable_sso": "enableSso",
+        "short_name": "shortName",
+    },
+)
+class CfnSimpleADProps:
+    def __init__(
+        self,
+        *,
+        name: str,
+        password: str,
+        size: str,
+        vpc_settings: typing.Union[
+            "CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e
+        ],
+        create_alias: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        description: typing.Optional[str] = None,
+        enable_sso: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        short_name: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::DirectoryService::SimpleAD``.
 
         :param name: ``AWS::DirectoryService::SimpleAD.Name``.
@@ -613,15 +785,19 @@ class CfnSimpleADProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html
         """
         self._values = {
-            'name': name,
-            'password': password,
-            'size': size,
-            'vpc_settings': vpc_settings,
+            "name": name,
+            "password": password,
+            "size": size,
+            "vpc_settings": vpc_settings,
         }
-        if create_alias is not None: self._values["create_alias"] = create_alias
-        if description is not None: self._values["description"] = description
-        if enable_sso is not None: self._values["enable_sso"] = enable_sso
-        if short_name is not None: self._values["short_name"] = short_name
+        if create_alias is not None:
+            self._values["create_alias"] = create_alias
+        if description is not None:
+            self._values["description"] = description
+        if enable_sso is not None:
+            self._values["enable_sso"] = enable_sso
+        if short_name is not None:
+            self._values["short_name"] = short_name
 
     @builtins.property
     def name(self) -> str:
@@ -630,7 +806,7 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def password(self) -> str:
@@ -639,7 +815,7 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
         """
-        return self._values.get('password')
+        return self._values.get("password")
 
     @builtins.property
     def size(self) -> str:
@@ -648,25 +824,29 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
         """
-        return self._values.get('size')
+        return self._values.get("size")
 
     @builtins.property
-    def vpc_settings(self) -> typing.Union["CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e]:
+    def vpc_settings(
+        self,
+    ) -> typing.Union["CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e]:
         """``AWS::DirectoryService::SimpleAD.VpcSettings``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
         """
-        return self._values.get('vpc_settings')
+        return self._values.get("vpc_settings")
 
     @builtins.property
-    def create_alias(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def create_alias(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-createalias
         """
-        return self._values.get('create_alias')
+        return self._values.get("create_alias")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -675,7 +855,7 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def enable_sso(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
@@ -684,7 +864,7 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-enablesso
         """
-        return self._values.get('enable_sso')
+        return self._values.get("enable_sso")
 
     @builtins.property
     def short_name(self) -> typing.Optional[str]:
@@ -693,7 +873,7 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-shortname
         """
-        return self._values.get('short_name')
+        return self._values.get("short_name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -702,7 +882,9 @@ class CfnSimpleADProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnSimpleADProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnSimpleADProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
