@@ -11,6 +11,7 @@ import publication
 from .._jsii import *
 
 from .. import Construct as _Construct_f50a3f53, Duration as _Duration_5170c158
+from ..aws_codeguruprofiler import IProfilingGroup as _IProfilingGroup_ca898ddc
 from ..aws_ec2 import (
     ISecurityGroup as _ISecurityGroup_d72ab8e8,
     IVpc as _IVpc_3795853f,
@@ -55,6 +56,7 @@ class Bundling(
         *,
         entry: str,
         runtime: _Runtime_8b970b80,
+        build_args: typing.Optional[typing.Mapping[str, str]] = None,
         cache_dir: typing.Optional[str] = None,
         external_modules: typing.Optional[typing.List[str]] = None,
         minify: typing.Optional[bool] = None,
@@ -68,6 +70,7 @@ class Bundling(
 
         :param entry: Entry file.
         :param runtime: The runtime of the lambda function.
+        :param build_args: Build arguments to pass when building the bundling image. Default: - no build arguments are passed
         :param cache_dir: The cache directory. Parcel uses a filesystem cache for fast rebuilds. Default: - ``.cache`` in the root directory
         :param external_modules: A list of modules that should be considered as externals (already available in the runtime). Default: ['aws-sdk']
         :param minify: Whether to minify files when bundling. Default: false
@@ -83,6 +86,7 @@ class Bundling(
         options = ParcelOptions(
             entry=entry,
             runtime=runtime,
+            build_args=build_args,
             cache_dir=cache_dir,
             external_modules=external_modules,
             minify=minify,
@@ -131,6 +135,8 @@ class NodejsFunction(
         ] = None,
         log_retention_role: typing.Optional[_IRole_e69bbae4] = None,
         memory_size: typing.Optional[jsii.Number] = None,
+        profiling: typing.Optional[bool] = None,
+        profiling_group: typing.Optional[_IProfilingGroup_ca898ddc] = None,
         reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
         security_group: typing.Optional[_ISecurityGroup_d72ab8e8] = None,
@@ -139,6 +145,7 @@ class NodejsFunction(
         tracing: typing.Optional[_Tracing_34f0a955] = None,
         vpc: typing.Optional[_IVpc_3795853f] = None,
         vpc_subnets: typing.Optional[_SubnetSelection_36a13cd6] = None,
+        build_args: typing.Optional[typing.Mapping[str, str]] = None,
         cache_dir: typing.Optional[str] = None,
         external_modules: typing.Optional[typing.List[str]] = None,
         minify: typing.Optional[bool] = None,
@@ -172,6 +179,8 @@ class NodejsFunction(
         :param log_retention_retry_options: When log retention is specified, a custom resource attempts to create the CloudWatch log group. These options control the retry policy when interacting with CloudWatch APIs. Default: - Default AWS SDK retry options.
         :param log_retention_role: The IAM role for the Lambda function associated with the custom resource that sets the retention policy. Default: - A new role is created.
         :param memory_size: The amount of memory, in MB, that is allocated to your Lambda function. Lambda uses this value to proportionally allocate the amount of CPU power. For more information, see Resource Model in the AWS Lambda Developer Guide. Default: 128
+        :param profiling: Enable profiling. Default: - No profiling.
+        :param profiling_group: Profiling Group. Default: - A new profiling group will be created if ``profiling`` is set.
         :param reserved_concurrent_executions: The maximum of concurrent executions you want to reserve for the function. Default: - No specific limit - account limit.
         :param role: Lambda execution role. This is the role that will be assumed by the function upon execution. It controls the permissions that the function will have. The Role must be assumable by the 'lambda.amazonaws.com' service principal. The default Role automatically has permissions granted for Lambda execution. If you provide a Role, you must add the relevant AWS managed policies yourself. The relevant managed policies are "service-role/AWSLambdaBasicExecutionRole" and "service-role/AWSLambdaVPCAccessExecutionRole". Default: - A unique role will be generated for this lambda function. Both supplied and generated roles can always be changed by calling ``addToRolePolicy``.
         :param security_group: What security group to associate with the Lambda's network interfaces. This property is being deprecated, consider using securityGroups instead. Only used if 'vpc' is supplied. Use securityGroups property instead. Function constructor will throw an error if both are specified. Default: - If the function is placed within a VPC and a security group is not specified, either by this or securityGroups prop, a dedicated security group will be created for this function.
@@ -180,6 +189,7 @@ class NodejsFunction(
         :param tracing: Enable AWS X-Ray Tracing for Lambda Function. Default: Tracing.Disabled
         :param vpc: VPC network to place Lambda network interfaces. Specify this if the Lambda function needs to access resources in a VPC. Default: - Function is not placed within a VPC.
         :param vpc_subnets: Where to place the network interfaces within the VPC. Only used if 'vpc' is supplied. Note: internet access for Lambdas requires a NAT gateway, so picking Public subnets is not allowed. Default: - the Vpc default strategy if not specified
+        :param build_args: Build arguments to pass when building the bundling image. Default: - no build arguments are passed
         :param cache_dir: The cache directory. Parcel uses a filesystem cache for fast rebuilds. Default: - ``.cache`` in the root directory
         :param external_modules: A list of modules that should be considered as externals (already available in the runtime). Default: ['aws-sdk']
         :param minify: Whether to minify files when bundling. Default: false
@@ -214,6 +224,8 @@ class NodejsFunction(
             log_retention_retry_options=log_retention_retry_options,
             log_retention_role=log_retention_role,
             memory_size=memory_size,
+            profiling=profiling,
+            profiling_group=profiling_group,
             reserved_concurrent_executions=reserved_concurrent_executions,
             role=role,
             security_group=security_group,
@@ -222,6 +234,7 @@ class NodejsFunction(
             tracing=tracing,
             vpc=vpc,
             vpc_subnets=vpc_subnets,
+            build_args=build_args,
             cache_dir=cache_dir,
             external_modules=external_modules,
             minify=minify,
@@ -243,6 +256,7 @@ class NodejsFunction(
     jsii_type="monocdk-experiment.aws_lambda_nodejs.ParcelBaseOptions",
     jsii_struct_bases=[],
     name_mapping={
+        "build_args": "buildArgs",
         "cache_dir": "cacheDir",
         "external_modules": "externalModules",
         "minify": "minify",
@@ -257,6 +271,7 @@ class ParcelBaseOptions:
     def __init__(
         self,
         *,
+        build_args: typing.Optional[typing.Mapping[str, str]] = None,
         cache_dir: typing.Optional[str] = None,
         external_modules: typing.Optional[typing.List[str]] = None,
         minify: typing.Optional[bool] = None,
@@ -268,6 +283,7 @@ class ParcelBaseOptions:
     ) -> None:
         """Base options for Parcel bundling.
 
+        :param build_args: Build arguments to pass when building the bundling image. Default: - no build arguments are passed
         :param cache_dir: The cache directory. Parcel uses a filesystem cache for fast rebuilds. Default: - ``.cache`` in the root directory
         :param external_modules: A list of modules that should be considered as externals (already available in the runtime). Default: ['aws-sdk']
         :param minify: Whether to minify files when bundling. Default: false
@@ -281,6 +297,8 @@ class ParcelBaseOptions:
         :stability: experimental
         """
         self._values = {}
+        if build_args is not None:
+            self._values["build_args"] = build_args
         if cache_dir is not None:
             self._values["cache_dir"] = cache_dir
         if external_modules is not None:
@@ -298,6 +316,18 @@ class ParcelBaseOptions:
         if source_maps is not None:
             self._values["source_maps"] = source_maps
 
+    @builtins.property
+    def build_args(self) -> typing.Optional[typing.Mapping[str, str]]:
+        """Build arguments to pass when building the bundling image.
+
+        default
+        :default: - no build arguments are passed
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("build_args")
+
     @builtins.property
     def cache_dir(self) -> typing.Optional[str]:
         """The cache directory.
@@ -420,6 +450,7 @@ class ParcelBaseOptions:
     jsii_type="monocdk-experiment.aws_lambda_nodejs.ParcelOptions",
     jsii_struct_bases=[ParcelBaseOptions],
     name_mapping={
+        "build_args": "buildArgs",
         "cache_dir": "cacheDir",
         "external_modules": "externalModules",
         "minify": "minify",
@@ -436,6 +467,7 @@ class ParcelOptions(ParcelBaseOptions):
     def __init__(
         self,
         *,
+        build_args: typing.Optional[typing.Mapping[str, str]] = None,
         cache_dir: typing.Optional[str] = None,
         external_modules: typing.Optional[typing.List[str]] = None,
         minify: typing.Optional[bool] = None,
@@ -449,6 +481,7 @@ class ParcelOptions(ParcelBaseOptions):
     ) -> None:
         """Options for Parcel bundling.
 
+        :param build_args: Build arguments to pass when building the bundling image. Default: - no build arguments are passed
         :param cache_dir: The cache directory. Parcel uses a filesystem cache for fast rebuilds. Default: - ``.cache`` in the root directory
         :param external_modules: A list of modules that should be considered as externals (already available in the runtime). Default: ['aws-sdk']
         :param minify: Whether to minify files when bundling. Default: false
@@ -467,6 +500,8 @@ class ParcelOptions(ParcelBaseOptions):
             "entry": entry,
             "runtime": runtime,
         }
+        if build_args is not None:
+            self._values["build_args"] = build_args
         if cache_dir is not None:
             self._values["cache_dir"] = cache_dir
         if external_modules is not None:
@@ -484,6 +519,18 @@ class ParcelOptions(ParcelBaseOptions):
         if source_maps is not None:
             self._values["source_maps"] = source_maps
 
+    @builtins.property
+    def build_args(self) -> typing.Optional[typing.Mapping[str, str]]:
+        """Build arguments to pass when building the bundling image.
+
+        default
+        :default: - no build arguments are passed
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("build_args")
+
     @builtins.property
     def cache_dir(self) -> typing.Optional[str]:
         """The cache directory.
@@ -642,6 +689,8 @@ class ParcelOptions(ParcelBaseOptions):
         "log_retention_retry_options": "logRetentionRetryOptions",
         "log_retention_role": "logRetentionRole",
         "memory_size": "memorySize",
+        "profiling": "profiling",
+        "profiling_group": "profilingGroup",
         "reserved_concurrent_executions": "reservedConcurrentExecutions",
         "role": "role",
         "security_group": "securityGroup",
@@ -650,6 +699,7 @@ class ParcelOptions(ParcelBaseOptions):
         "tracing": "tracing",
         "vpc": "vpc",
         "vpc_subnets": "vpcSubnets",
+        "build_args": "buildArgs",
         "cache_dir": "cacheDir",
         "external_modules": "externalModules",
         "minify": "minify",
@@ -687,6 +737,8 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         ] = None,
         log_retention_role: typing.Optional[_IRole_e69bbae4] = None,
         memory_size: typing.Optional[jsii.Number] = None,
+        profiling: typing.Optional[bool] = None,
+        profiling_group: typing.Optional[_IProfilingGroup_ca898ddc] = None,
         reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
         security_group: typing.Optional[_ISecurityGroup_d72ab8e8] = None,
@@ -695,6 +747,7 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         tracing: typing.Optional[_Tracing_34f0a955] = None,
         vpc: typing.Optional[_IVpc_3795853f] = None,
         vpc_subnets: typing.Optional[_SubnetSelection_36a13cd6] = None,
+        build_args: typing.Optional[typing.Mapping[str, str]] = None,
         cache_dir: typing.Optional[str] = None,
         external_modules: typing.Optional[typing.List[str]] = None,
         minify: typing.Optional[bool] = None,
@@ -727,6 +780,8 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         :param log_retention_retry_options: When log retention is specified, a custom resource attempts to create the CloudWatch log group. These options control the retry policy when interacting with CloudWatch APIs. Default: - Default AWS SDK retry options.
         :param log_retention_role: The IAM role for the Lambda function associated with the custom resource that sets the retention policy. Default: - A new role is created.
         :param memory_size: The amount of memory, in MB, that is allocated to your Lambda function. Lambda uses this value to proportionally allocate the amount of CPU power. For more information, see Resource Model in the AWS Lambda Developer Guide. Default: 128
+        :param profiling: Enable profiling. Default: - No profiling.
+        :param profiling_group: Profiling Group. Default: - A new profiling group will be created if ``profiling`` is set.
         :param reserved_concurrent_executions: The maximum of concurrent executions you want to reserve for the function. Default: - No specific limit - account limit.
         :param role: Lambda execution role. This is the role that will be assumed by the function upon execution. It controls the permissions that the function will have. The Role must be assumable by the 'lambda.amazonaws.com' service principal. The default Role automatically has permissions granted for Lambda execution. If you provide a Role, you must add the relevant AWS managed policies yourself. The relevant managed policies are "service-role/AWSLambdaBasicExecutionRole" and "service-role/AWSLambdaVPCAccessExecutionRole". Default: - A unique role will be generated for this lambda function. Both supplied and generated roles can always be changed by calling ``addToRolePolicy``.
         :param security_group: What security group to associate with the Lambda's network interfaces. This property is being deprecated, consider using securityGroups instead. Only used if 'vpc' is supplied. Use securityGroups property instead. Function constructor will throw an error if both are specified. Default: - If the function is placed within a VPC and a security group is not specified, either by this or securityGroups prop, a dedicated security group will be created for this function.
@@ -735,6 +790,7 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         :param tracing: Enable AWS X-Ray Tracing for Lambda Function. Default: Tracing.Disabled
         :param vpc: VPC network to place Lambda network interfaces. Specify this if the Lambda function needs to access resources in a VPC. Default: - Function is not placed within a VPC.
         :param vpc_subnets: Where to place the network interfaces within the VPC. Only used if 'vpc' is supplied. Note: internet access for Lambdas requires a NAT gateway, so picking Public subnets is not allowed. Default: - the Vpc default strategy if not specified
+        :param build_args: Build arguments to pass when building the bundling image. Default: - no build arguments are passed
         :param cache_dir: The cache directory. Parcel uses a filesystem cache for fast rebuilds. Default: - ``.cache`` in the root directory
         :param external_modules: A list of modules that should be considered as externals (already available in the runtime). Default: ['aws-sdk']
         :param minify: Whether to minify files when bundling. Default: false
@@ -797,6 +853,10 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
             self._values["log_retention_role"] = log_retention_role
         if memory_size is not None:
             self._values["memory_size"] = memory_size
+        if profiling is not None:
+            self._values["profiling"] = profiling
+        if profiling_group is not None:
+            self._values["profiling_group"] = profiling_group
         if reserved_concurrent_executions is not None:
             self._values[
                 "reserved_concurrent_executions"
@@ -815,6 +875,8 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
             self._values["vpc"] = vpc
         if vpc_subnets is not None:
             self._values["vpc_subnets"] = vpc_subnets
+        if build_args is not None:
+            self._values["build_args"] = build_args
         if cache_dir is not None:
             self._values["cache_dir"] = cache_dir
         if external_modules is not None:
@@ -1093,6 +1155,34 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         """
         return self._values.get("memory_size")
 
+    @builtins.property
+    def profiling(self) -> typing.Optional[bool]:
+        """Enable profiling.
+
+        default
+        :default: - No profiling.
+
+        see
+        :see: https://docs.aws.amazon.com/codeguru/latest/profiler-ug/setting-up-lambda.html
+        stability
+        :stability: experimental
+        """
+        return self._values.get("profiling")
+
+    @builtins.property
+    def profiling_group(self) -> typing.Optional[_IProfilingGroup_ca898ddc]:
+        """Profiling Group.
+
+        default
+        :default: - A new profiling group will be created if ``profiling`` is set.
+
+        see
+        :see: https://docs.aws.amazon.com/codeguru/latest/profiler-ug/setting-up-lambda.html
+        stability
+        :stability: experimental
+        """
+        return self._values.get("profiling_group")
+
     @builtins.property
     def reserved_concurrent_executions(self) -> typing.Optional[jsii.Number]:
         """The maximum of concurrent executions you want to reserve for the function.
@@ -1230,6 +1320,18 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         """
         return self._values.get("vpc_subnets")
 
+    @builtins.property
+    def build_args(self) -> typing.Optional[typing.Mapping[str, str]]:
+        """Build arguments to pass when building the bundling image.
+
+        default
+        :default: - no build arguments are passed
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("build_args")
+
     @builtins.property
     def cache_dir(self) -> typing.Optional[str]:
         """The cache directory.
