@@ -10,13 +10,22 @@ import publication
 
 from .._jsii import *
 
-from ..aws_lambda import (IFunction as _IFunction_1c1de0bc)
-from ..aws_sns import (TopicSubscriptionConfig as _TopicSubscriptionConfig_2ddb92c9, ITopic as _ITopic_ef0ebe0e, ITopicSubscription as _ITopicSubscription_5303fec1, SubscriptionFilter as _SubscriptionFilter_91537200, SubscriptionProtocol as _SubscriptionProtocol_3d1a4bcf)
-from ..aws_sqs import (IQueue as _IQueue_b743f559)
+from ..aws_lambda import IFunction as _IFunction_1c1de0bc
+from ..aws_sns import (
+    TopicSubscriptionConfig as _TopicSubscriptionConfig_2ddb92c9,
+    ITopic as _ITopic_ef0ebe0e,
+    ITopicSubscription as _ITopicSubscription_5303fec1,
+    SubscriptionFilter as _SubscriptionFilter_91537200,
+    SubscriptionProtocol as _SubscriptionProtocol_3d1a4bcf,
+)
+from ..aws_sqs import IQueue as _IQueue_b743f559
 
 
 @jsii.implements(_ITopicSubscription_5303fec1)
-class EmailSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_sns_subscriptions.EmailSubscription"):
+class EmailSubscription(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.EmailSubscription",
+):
     """Use an email address as a subscription target.
 
     Email subscriptions require confirmation.
@@ -24,7 +33,17 @@ class EmailSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.a
     stability
     :stability: experimental
     """
-    def __init__(self, email_address: str, *, json: typing.Optional[bool]=None, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None) -> None:
+
+    def __init__(
+        self,
+        email_address: str,
+        *,
+        json: typing.Optional[bool] = None,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+    ) -> None:
         """
         :param email_address: -
         :param json: Indicates if the full notification JSON should be sent to the email address or just the message text. Default: false (Message text)
@@ -34,7 +53,9 @@ class EmailSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.a
         stability
         :stability: experimental
         """
-        props = EmailSubscriptionProps(json=json, dead_letter_queue=dead_letter_queue, filter_policy=filter_policy)
+        props = EmailSubscriptionProps(
+            json=json, dead_letter_queue=dead_letter_queue, filter_policy=filter_policy
+        )
 
         jsii.create(EmailSubscription, self, [email_address, props])
 
@@ -51,13 +72,25 @@ class EmailSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.a
 
 
 @jsii.implements(_ITopicSubscription_5303fec1)
-class LambdaSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_sns_subscriptions.LambdaSubscription"):
+class LambdaSubscription(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.LambdaSubscription",
+):
     """Use a Lambda function as a subscription target.
 
     stability
     :stability: experimental
     """
-    def __init__(self, fn: _IFunction_1c1de0bc, *, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None) -> None:
+
+    def __init__(
+        self,
+        fn: _IFunction_1c1de0bc,
+        *,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+    ) -> None:
         """
         :param fn: -
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
@@ -66,7 +99,9 @@ class LambdaSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.
         stability
         :stability: experimental
         """
-        props = LambdaSubscriptionProps(dead_letter_queue=dead_letter_queue, filter_policy=filter_policy)
+        props = LambdaSubscriptionProps(
+            dead_letter_queue=dead_letter_queue, filter_policy=filter_policy
+        )
 
         jsii.create(LambdaSubscription, self, [fn, props])
 
@@ -83,13 +118,25 @@ class LambdaSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.
 
 
 @jsii.implements(_ITopicSubscription_5303fec1)
-class SmsSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_sns_subscriptions.SmsSubscription"):
+class SmsSubscription(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.SmsSubscription",
+):
     """Use an sms address as a subscription target.
 
     stability
     :stability: experimental
     """
-    def __init__(self, phone_number: str, *, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None) -> None:
+
+    def __init__(
+        self,
+        phone_number: str,
+        *,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+    ) -> None:
         """
         :param phone_number: -
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
@@ -98,7 +145,9 @@ class SmsSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws
         stability
         :stability: experimental
         """
-        props = SmsSubscriptionProps(dead_letter_queue=dead_letter_queue, filter_policy=filter_policy)
+        props = SmsSubscriptionProps(
+            dead_letter_queue=dead_letter_queue, filter_policy=filter_policy
+        )
 
         jsii.create(SmsSubscription, self, [phone_number, props])
 
@@ -115,13 +164,26 @@ class SmsSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws
 
 
 @jsii.implements(_ITopicSubscription_5303fec1)
-class SqsSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_sns_subscriptions.SqsSubscription"):
+class SqsSubscription(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.SqsSubscription",
+):
     """Use an SQS queue as a subscription target.
 
     stability
     :stability: experimental
     """
-    def __init__(self, queue: _IQueue_b743f559, *, raw_message_delivery: typing.Optional[bool]=None, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None) -> None:
+
+    def __init__(
+        self,
+        queue: _IQueue_b743f559,
+        *,
+        raw_message_delivery: typing.Optional[bool] = None,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+    ) -> None:
         """
         :param queue: -
         :param raw_message_delivery: The message to the queue is the same as it was sent to the topic. If false, the message will be wrapped in an SNS envelope. Default: false
@@ -131,7 +193,11 @@ class SqsSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws
         stability
         :stability: experimental
         """
-        props = SqsSubscriptionProps(raw_message_delivery=raw_message_delivery, dead_letter_queue=dead_letter_queue, filter_policy=filter_policy)
+        props = SqsSubscriptionProps(
+            raw_message_delivery=raw_message_delivery,
+            dead_letter_queue=dead_letter_queue,
+            filter_policy=filter_policy,
+        )
 
         jsii.create(SqsSubscription, self, [queue, props])
 
@@ -147,9 +213,23 @@ class SqsSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws
         return jsii.invoke(self, "bind", [topic])
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_sns_subscriptions.SubscriptionProps", jsii_struct_bases=[], name_mapping={'dead_letter_queue': 'deadLetterQueue', 'filter_policy': 'filterPolicy'})
-class SubscriptionProps():
-    def __init__(self, *, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.SubscriptionProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "dead_letter_queue": "deadLetterQueue",
+        "filter_policy": "filterPolicy",
+    },
+)
+class SubscriptionProps:
+    def __init__(
+        self,
+        *,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+    ) -> None:
         """Options to subscribing to an SNS topic.
 
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
@@ -158,10 +238,11 @@ class SubscriptionProps():
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if dead_letter_queue is not None: self._values["dead_letter_queue"] = dead_letter_queue
-        if filter_policy is not None: self._values["filter_policy"] = filter_policy
+        self._values = {}
+        if dead_letter_queue is not None:
+            self._values["dead_letter_queue"] = dead_letter_queue
+        if filter_policy is not None:
+            self._values["filter_policy"] = filter_policy
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
@@ -175,10 +256,12 @@ class SubscriptionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('dead_letter_queue')
+        return self._values.get("dead_letter_queue")
 
     @builtins.property
-    def filter_policy(self) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    def filter_policy(
+        self,
+    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -187,7 +270,7 @@ class SubscriptionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('filter_policy')
+        return self._values.get("filter_policy")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -196,11 +279,16 @@ class SubscriptionProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'SubscriptionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "SubscriptionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_ITopicSubscription_5303fec1)
-class UrlSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_sns_subscriptions.UrlSubscription"):
+class UrlSubscription(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.UrlSubscription",
+):
     """Use a URL as a subscription target.
 
     The message will be POSTed to the given URL.
@@ -210,7 +298,18 @@ class UrlSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws
     stability
     :stability: experimental
     """
-    def __init__(self, url: str, *, protocol: typing.Optional[_SubscriptionProtocol_3d1a4bcf]=None, raw_message_delivery: typing.Optional[bool]=None, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None) -> None:
+
+    def __init__(
+        self,
+        url: str,
+        *,
+        protocol: typing.Optional[_SubscriptionProtocol_3d1a4bcf] = None,
+        raw_message_delivery: typing.Optional[bool] = None,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+    ) -> None:
         """
         :param url: -
         :param protocol: The subscription's protocol. Default: - Protocol is derived from url
@@ -221,7 +320,12 @@ class UrlSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws
         stability
         :stability: experimental
         """
-        props = UrlSubscriptionProps(protocol=protocol, raw_message_delivery=raw_message_delivery, dead_letter_queue=dead_letter_queue, filter_policy=filter_policy)
+        props = UrlSubscriptionProps(
+            protocol=protocol,
+            raw_message_delivery=raw_message_delivery,
+            dead_letter_queue=dead_letter_queue,
+            filter_policy=filter_policy,
+        )
 
         jsii.create(UrlSubscription, self, [url, props])
 
@@ -237,9 +341,27 @@ class UrlSubscription(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws
         return jsii.invoke(self, "bind", [_topic])
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_sns_subscriptions.UrlSubscriptionProps", jsii_struct_bases=[SubscriptionProps], name_mapping={'dead_letter_queue': 'deadLetterQueue', 'filter_policy': 'filterPolicy', 'protocol': 'protocol', 'raw_message_delivery': 'rawMessageDelivery'})
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.UrlSubscriptionProps",
+    jsii_struct_bases=[SubscriptionProps],
+    name_mapping={
+        "dead_letter_queue": "deadLetterQueue",
+        "filter_policy": "filterPolicy",
+        "protocol": "protocol",
+        "raw_message_delivery": "rawMessageDelivery",
+    },
+)
 class UrlSubscriptionProps(SubscriptionProps):
-    def __init__(self, *, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None, protocol: typing.Optional[_SubscriptionProtocol_3d1a4bcf]=None, raw_message_delivery: typing.Optional[bool]=None) -> None:
+    def __init__(
+        self,
+        *,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+        protocol: typing.Optional[_SubscriptionProtocol_3d1a4bcf] = None,
+        raw_message_delivery: typing.Optional[bool] = None,
+    ) -> None:
         """Options for URL subscriptions.
 
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
@@ -250,12 +372,15 @@ class UrlSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if dead_letter_queue is not None: self._values["dead_letter_queue"] = dead_letter_queue
-        if filter_policy is not None: self._values["filter_policy"] = filter_policy
-        if protocol is not None: self._values["protocol"] = protocol
-        if raw_message_delivery is not None: self._values["raw_message_delivery"] = raw_message_delivery
+        self._values = {}
+        if dead_letter_queue is not None:
+            self._values["dead_letter_queue"] = dead_letter_queue
+        if filter_policy is not None:
+            self._values["filter_policy"] = filter_policy
+        if protocol is not None:
+            self._values["protocol"] = protocol
+        if raw_message_delivery is not None:
+            self._values["raw_message_delivery"] = raw_message_delivery
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
@@ -269,10 +394,12 @@ class UrlSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('dead_letter_queue')
+        return self._values.get("dead_letter_queue")
 
     @builtins.property
-    def filter_policy(self) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    def filter_policy(
+        self,
+    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -281,7 +408,7 @@ class UrlSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('filter_policy')
+        return self._values.get("filter_policy")
 
     @builtins.property
     def protocol(self) -> typing.Optional[_SubscriptionProtocol_3d1a4bcf]:
@@ -293,7 +420,7 @@ class UrlSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('protocol')
+        return self._values.get("protocol")
 
     @builtins.property
     def raw_message_delivery(self) -> typing.Optional[bool]:
@@ -307,7 +434,7 @@ class UrlSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('raw_message_delivery')
+        return self._values.get("raw_message_delivery")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -316,12 +443,30 @@ class UrlSubscriptionProps(SubscriptionProps):
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'UrlSubscriptionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "UrlSubscriptionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_sns_subscriptions.EmailSubscriptionProps", jsii_struct_bases=[SubscriptionProps], name_mapping={'dead_letter_queue': 'deadLetterQueue', 'filter_policy': 'filterPolicy', 'json': 'json'})
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.EmailSubscriptionProps",
+    jsii_struct_bases=[SubscriptionProps],
+    name_mapping={
+        "dead_letter_queue": "deadLetterQueue",
+        "filter_policy": "filterPolicy",
+        "json": "json",
+    },
+)
 class EmailSubscriptionProps(SubscriptionProps):
-    def __init__(self, *, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None, json: typing.Optional[bool]=None) -> None:
+    def __init__(
+        self,
+        *,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+        json: typing.Optional[bool] = None,
+    ) -> None:
         """Options for email subscriptions.
 
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
@@ -331,11 +476,13 @@ class EmailSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if dead_letter_queue is not None: self._values["dead_letter_queue"] = dead_letter_queue
-        if filter_policy is not None: self._values["filter_policy"] = filter_policy
-        if json is not None: self._values["json"] = json
+        self._values = {}
+        if dead_letter_queue is not None:
+            self._values["dead_letter_queue"] = dead_letter_queue
+        if filter_policy is not None:
+            self._values["filter_policy"] = filter_policy
+        if json is not None:
+            self._values["json"] = json
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
@@ -349,10 +496,12 @@ class EmailSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('dead_letter_queue')
+        return self._values.get("dead_letter_queue")
 
     @builtins.property
-    def filter_policy(self) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    def filter_policy(
+        self,
+    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -361,7 +510,7 @@ class EmailSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('filter_policy')
+        return self._values.get("filter_policy")
 
     @builtins.property
     def json(self) -> typing.Optional[bool]:
@@ -373,7 +522,7 @@ class EmailSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('json')
+        return self._values.get("json")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -382,12 +531,28 @@ class EmailSubscriptionProps(SubscriptionProps):
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'EmailSubscriptionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "EmailSubscriptionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_sns_subscriptions.LambdaSubscriptionProps", jsii_struct_bases=[SubscriptionProps], name_mapping={'dead_letter_queue': 'deadLetterQueue', 'filter_policy': 'filterPolicy'})
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.LambdaSubscriptionProps",
+    jsii_struct_bases=[SubscriptionProps],
+    name_mapping={
+        "dead_letter_queue": "deadLetterQueue",
+        "filter_policy": "filterPolicy",
+    },
+)
 class LambdaSubscriptionProps(SubscriptionProps):
-    def __init__(self, *, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None) -> None:
+    def __init__(
+        self,
+        *,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+    ) -> None:
         """Properties for a Lambda subscription.
 
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
@@ -396,10 +561,11 @@ class LambdaSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if dead_letter_queue is not None: self._values["dead_letter_queue"] = dead_letter_queue
-        if filter_policy is not None: self._values["filter_policy"] = filter_policy
+        self._values = {}
+        if dead_letter_queue is not None:
+            self._values["dead_letter_queue"] = dead_letter_queue
+        if filter_policy is not None:
+            self._values["filter_policy"] = filter_policy
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
@@ -413,10 +579,12 @@ class LambdaSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('dead_letter_queue')
+        return self._values.get("dead_letter_queue")
 
     @builtins.property
-    def filter_policy(self) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    def filter_policy(
+        self,
+    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -425,7 +593,7 @@ class LambdaSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('filter_policy')
+        return self._values.get("filter_policy")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -434,12 +602,28 @@ class LambdaSubscriptionProps(SubscriptionProps):
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'LambdaSubscriptionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "LambdaSubscriptionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_sns_subscriptions.SmsSubscriptionProps", jsii_struct_bases=[SubscriptionProps], name_mapping={'dead_letter_queue': 'deadLetterQueue', 'filter_policy': 'filterPolicy'})
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.SmsSubscriptionProps",
+    jsii_struct_bases=[SubscriptionProps],
+    name_mapping={
+        "dead_letter_queue": "deadLetterQueue",
+        "filter_policy": "filterPolicy",
+    },
+)
 class SmsSubscriptionProps(SubscriptionProps):
-    def __init__(self, *, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None) -> None:
+    def __init__(
+        self,
+        *,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+    ) -> None:
         """Options for SMS subscriptions.
 
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
@@ -448,10 +632,11 @@ class SmsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if dead_letter_queue is not None: self._values["dead_letter_queue"] = dead_letter_queue
-        if filter_policy is not None: self._values["filter_policy"] = filter_policy
+        self._values = {}
+        if dead_letter_queue is not None:
+            self._values["dead_letter_queue"] = dead_letter_queue
+        if filter_policy is not None:
+            self._values["filter_policy"] = filter_policy
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
@@ -465,10 +650,12 @@ class SmsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('dead_letter_queue')
+        return self._values.get("dead_letter_queue")
 
     @builtins.property
-    def filter_policy(self) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    def filter_policy(
+        self,
+    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -477,7 +664,7 @@ class SmsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('filter_policy')
+        return self._values.get("filter_policy")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -486,12 +673,30 @@ class SmsSubscriptionProps(SubscriptionProps):
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'SmsSubscriptionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "SmsSubscriptionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_sns_subscriptions.SqsSubscriptionProps", jsii_struct_bases=[SubscriptionProps], name_mapping={'dead_letter_queue': 'deadLetterQueue', 'filter_policy': 'filterPolicy', 'raw_message_delivery': 'rawMessageDelivery'})
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_sns_subscriptions.SqsSubscriptionProps",
+    jsii_struct_bases=[SubscriptionProps],
+    name_mapping={
+        "dead_letter_queue": "deadLetterQueue",
+        "filter_policy": "filterPolicy",
+        "raw_message_delivery": "rawMessageDelivery",
+    },
+)
 class SqsSubscriptionProps(SubscriptionProps):
-    def __init__(self, *, dead_letter_queue: typing.Optional[_IQueue_b743f559]=None, filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]=None, raw_message_delivery: typing.Optional[bool]=None) -> None:
+    def __init__(
+        self,
+        *,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[
+            typing.Mapping[str, _SubscriptionFilter_91537200]
+        ] = None,
+        raw_message_delivery: typing.Optional[bool] = None,
+    ) -> None:
         """Properties for an SQS subscription.
 
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
@@ -501,11 +706,13 @@ class SqsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if dead_letter_queue is not None: self._values["dead_letter_queue"] = dead_letter_queue
-        if filter_policy is not None: self._values["filter_policy"] = filter_policy
-        if raw_message_delivery is not None: self._values["raw_message_delivery"] = raw_message_delivery
+        self._values = {}
+        if dead_letter_queue is not None:
+            self._values["dead_letter_queue"] = dead_letter_queue
+        if filter_policy is not None:
+            self._values["filter_policy"] = filter_policy
+        if raw_message_delivery is not None:
+            self._values["raw_message_delivery"] = raw_message_delivery
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
@@ -519,10 +726,12 @@ class SqsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('dead_letter_queue')
+        return self._values.get("dead_letter_queue")
 
     @builtins.property
-    def filter_policy(self) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    def filter_policy(
+        self,
+    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -531,7 +740,7 @@ class SqsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('filter_policy')
+        return self._values.get("filter_policy")
 
     @builtins.property
     def raw_message_delivery(self) -> typing.Optional[bool]:
@@ -545,7 +754,7 @@ class SqsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get('raw_message_delivery')
+        return self._values.get("raw_message_delivery")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -554,7 +763,9 @@ class SqsSubscriptionProps(SubscriptionProps):
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'SqsSubscriptionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "SqsSubscriptionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
