@@ -649,6 +649,7 @@ class Provider(
         *,
         on_event_handler: _IFunction_1c1de0bc,
         is_complete_handler: typing.Optional[_IFunction_1c1de0bc] = None,
+        log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
         query_interval: typing.Optional[_Duration_5170c158] = None,
         total_timeout: typing.Optional[_Duration_5170c158] = None,
     ) -> None:
@@ -657,6 +658,7 @@ class Provider(
         :param id: -
         :param on_event_handler: The AWS Lambda function to invoke for all resource lifecycle operations (CREATE/UPDATE/DELETE). This function is responsible to begin the requested resource operation (CREATE/UPDATE/DELETE) and return any additional properties to add to the event, which will later be passed to ``isComplete``. The ``PhysicalResourceId`` property must be included in the response.
         :param is_complete_handler: The AWS Lambda function to invoke in order to determine if the operation is complete. This function will be called immediately after ``onEvent`` and then periodically based on the configured query interval as long as it returns ``false``. If the function still returns ``false`` and the alloted timeout has passed, the operation will fail. Default: - provider is synchronous. This means that the ``onEvent`` handler is expected to finish all lifecycle operations within the initial invocation.
+        :param log_retention: The number of days framework log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.INFINITE
         :param query_interval: Time between calls to the ``isComplete`` handler which determines if the resource has been stabilized. The first ``isComplete`` will be called immediately after ``handler`` and then every ``queryInterval`` seconds, and until ``timeout`` has been reached or until ``isComplete`` returns ``true``. Default: Duration.seconds(5)
         :param total_timeout: Total timeout for the entire operation. The maximum timeout is 2 hours (yes, it can exceed the AWS Lambda 15 minutes) Default: Duration.minutes(30)
 
@@ -666,6 +668,7 @@ class Provider(
         props = ProviderProps(
             on_event_handler=on_event_handler,
             is_complete_handler=is_complete_handler,
+            log_retention=log_retention,
             query_interval=query_interval,
             total_timeout=total_timeout,
         )
@@ -723,6 +726,7 @@ class Provider(
     name_mapping={
         "on_event_handler": "onEventHandler",
         "is_complete_handler": "isCompleteHandler",
+        "log_retention": "logRetention",
         "query_interval": "queryInterval",
         "total_timeout": "totalTimeout",
     },
@@ -733,6 +737,7 @@ class ProviderProps:
         *,
         on_event_handler: _IFunction_1c1de0bc,
         is_complete_handler: typing.Optional[_IFunction_1c1de0bc] = None,
+        log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
         query_interval: typing.Optional[_Duration_5170c158] = None,
         total_timeout: typing.Optional[_Duration_5170c158] = None,
     ) -> None:
@@ -740,6 +745,7 @@ class ProviderProps:
 
         :param on_event_handler: The AWS Lambda function to invoke for all resource lifecycle operations (CREATE/UPDATE/DELETE). This function is responsible to begin the requested resource operation (CREATE/UPDATE/DELETE) and return any additional properties to add to the event, which will later be passed to ``isComplete``. The ``PhysicalResourceId`` property must be included in the response.
         :param is_complete_handler: The AWS Lambda function to invoke in order to determine if the operation is complete. This function will be called immediately after ``onEvent`` and then periodically based on the configured query interval as long as it returns ``false``. If the function still returns ``false`` and the alloted timeout has passed, the operation will fail. Default: - provider is synchronous. This means that the ``onEvent`` handler is expected to finish all lifecycle operations within the initial invocation.
+        :param log_retention: The number of days framework log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.INFINITE
         :param query_interval: Time between calls to the ``isComplete`` handler which determines if the resource has been stabilized. The first ``isComplete`` will be called immediately after ``handler`` and then every ``queryInterval`` seconds, and until ``timeout`` has been reached or until ``isComplete`` returns ``true``. Default: Duration.seconds(5)
         :param total_timeout: Total timeout for the entire operation. The maximum timeout is 2 hours (yes, it can exceed the AWS Lambda 15 minutes) Default: Duration.minutes(30)
 
@@ -751,6 +757,8 @@ class ProviderProps:
         }
         if is_complete_handler is not None:
             self._values["is_complete_handler"] = is_complete_handler
+        if log_retention is not None:
+            self._values["log_retention"] = log_retention
         if query_interval is not None:
             self._values["query_interval"] = query_interval
         if total_timeout is not None:
@@ -790,6 +798,22 @@ class ProviderProps:
         """
         return self._values.get("is_complete_handler")
 
+    @builtins.property
+    def log_retention(self) -> typing.Optional[_RetentionDays_bdc7ad1f]:
+        """The number of days framework log events are kept in CloudWatch Logs.
+
+        When
+        updating this property, unsetting it doesn't remove the log retention policy.
+        To remove the retention policy, set the value to ``INFINITE``.
+
+        default
+        :default: logs.RetentionDays.INFINITE
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("log_retention")
+
     @builtins.property
     def query_interval(self) -> typing.Optional[_Duration_5170c158]:
         """Time between calls to the ``isComplete`` handler which determines if the resource has been stabilized.
